@@ -1,14 +1,19 @@
 """Events module."""
+from __future__ import annotations
 
 from dataclasses import dataclass
 from enum import Enum, unique
-from typing import Any, Optional
+from typing import TYPE_CHECKING, Any
 
-from ..events.base import Event
-from ..models import Room, VacuumState
-from ..util import DisplayNameIntEnum
+from deebot_client.events.base import Event
+from deebot_client.util import DisplayNameIntEnum
+
+from .efficiency_mode import EfficiencyMode, EfficiencyModeEvent
+from .fan_speed import FanSpeedEvent, FanSpeedLevel
 from .map import (
+    CachedMapInfoEvent,
     MajorMapEvent,
+    MapChangedEvent,
     MapSetEvent,
     MapSetType,
     MapSubsetEvent,
@@ -18,7 +23,39 @@ from .map import (
     PositionsEvent,
     PositionType,
 )
+from .network import NetworkInfoEvent
 from .water_info import WaterAmount, WaterInfoEvent
+from .work_mode import WorkMode, WorkModeEvent
+
+if TYPE_CHECKING:
+    from deebot_client.models import Room, State
+
+__all__ = [
+    "BatteryEvent",
+    "CachedMapInfoEvent",
+    "CleanJobStatus",
+    "CleanLogEntry",
+    "EfficiencyMode",
+    "EfficiencyModeEvent",
+    "Event",
+    "FanSpeedEvent",
+    "FanSpeedLevel",
+    "MajorMapEvent",
+    "MapChangedEvent",
+    "MapSetEvent",
+    "MapSetType",
+    "MapSubsetEvent",
+    "MapTraceEvent",
+    "MinorMapEvent",
+    "NetworkInfoEvent",
+    "Position",
+    "PositionType",
+    "PositionsEvent",
+    "WaterAmount",
+    "WaterInfoEvent",
+    "WorkMode",
+    "WorkModeEvent",
+]
 
 
 @dataclass(frozen=True)
@@ -81,20 +118,19 @@ class ErrorEvent(Event):
     description: str | None
 
 
-@dataclass(frozen=True)
-class FanSpeedEvent(Event):
-    """Fan speed event representation."""
-
-    speed: str
-
-
 @unique
 class LifeSpan(str, Enum):
     """Enum class for all possible life span components."""
 
-    SIDE_BRUSH = "sideBrush"
     BRUSH = "brush"
     FILTER = "heap"
+    SIDE_BRUSH = "sideBrush"
+    UNIT_CARE = "unitCare"
+    ROUND_MOP = "roundMop"
+    AIR_FRESHENER = "dModule"
+    UV_SANITIZER = "uv"
+    HUMIDIFY = "humidify"
+    HUMIDIFY_MAINTENANCE = "wbCare"
 
 
 @dataclass(frozen=True)
@@ -140,12 +176,18 @@ class TotalStatsEvent(Event):
     cleanings: int
 
 
-@dataclass(frozen=True)
-class StatusEvent(Event):
-    """Status event representation."""
+@dataclass(frozen=True, kw_only=True)
+class AvailabilityEvent(Event):
+    """Availability event."""
 
     available: bool
-    state: VacuumState | None
+
+
+@dataclass(frozen=True)
+class StateEvent(Event):
+    """State event representation."""
+
+    state: State
 
 
 @dataclass(frozen=True)
@@ -191,3 +233,8 @@ class MultimapStateEvent(EnableEvent):
 @dataclass(frozen=True)
 class TrueDetectEvent(EnableEvent):
     """TrueDetect event."""
+
+
+@dataclass(frozen=True)
+class VoiceAssistantStateEvent(EnableEvent):
+    """VoiceAssistantState event."""
