@@ -1,4 +1,5 @@
 """Deebot client exception module."""
+from __future__ import annotations
 
 
 class DeebotError(Exception):
@@ -21,5 +22,5 @@ class MapError(DeebotError):
     """Map error."""
 
 
-class NotInitializedError(DeebotError):
-    """Thrown when not class was not initialized correctly."""
+class MqttError(DeebotError):
+    """Mqtt error."""
